@@ -17,7 +17,7 @@
 """
 import unittest
 import sys
-import os.path
+import os
 sys.path.append(os.path.abspath('src'))
 import backup2swift.command as c
 import backup2swift_tests.test_vars as v
@@ -30,4 +30,5 @@ class CommandTests(unittest.TestCase):
                          c.check_config_file(v.config_file))
 
     def test_check_config_file_fail(self):
-        self.assertRaises(IOError, c.check_config_file, None)
+        if not os.path.isfile(os.path.join(os.environ['HOME'], '.bu2sw.conf')):
+            self.assertRaises(IOError, c.check_config_file, None)
